# 39 "java/java_lexer.mll"
 

  open Java_parser
  open Lexing
  open Java_ast

  type location = position * position

  let loc lexbuf : location = 
    (lexeme_start_p lexbuf, lexeme_end_p lexbuf)

  exception Lexical_error of location * string
  exception Syntax_error of location
  exception Dotdot of string


  let lex_error lexbuf s = raise (Lexical_error(loc lexbuf,s))

  let buf = Buffer.create 97

  let kw_table = 
    let table = Hashtbl.create 17 in
    let _ = 
      List.iter
	(fun (s,t) -> Hashtbl.add table s t)
	[ "abstract", ABSTRACT;
	  "assert", ASSERT;
	  "assigns", ASSIGNS;
	  "axiom", AXIOM;
	  "behavior", BEHAVIOR;
	  "boolean", BOOLEAN;
	  "break", BREAK;
	  "byte", BYTE;
	  "byvalue", BYVALUE;
	  "case", CASE;
	  "cast", CAST;
	  "catch", CATCH;
	  "char", CHAR;
	  "class", CLASS;
	  "const", CONST;
	  "continue", CONTINUE;
	  "decreases", DECREASES;
	  "default", DEFAULT;
	  "do", DO;
	  "double", DOUBLE;
	  "else", ELSE;
	  "ensures", ENSURES;
	  "extends", EXTENDS;
	  "false", FALSE;
	  "final", FINAL;
	  "finally", FINALLY;
	  "float", FLOAT;
	  "for", FOR;
	  "future", FUTURE;
	  "generic", GENERIC;
	  "ghost", GHOST;
	  "goto", GOTO;
	  "if", IF;
	  "implements", IMPLEMENTS;
	  "import", IMPORT;
	  "inner", INNER;
	  "instanceof", INSTANCEOF;
	  "int", INT;
	  "integer", INTEGER;
	  "interface", INTERFACE;
	  "invariant", INVARIANT;
	  "logic", LOGIC;
	  "long", LONG;
	  "loop_invariant", LOOP_INVARIANT;
	  "model", MODEL;
	  "native", NATIVE;
	  "new", NEW;
	  "non_null", NON_NULL;
	  "null", NULL;
	  "nullable", NULLABLE;
	  "operator", OPERATOR;
	  "outer", OUTER;
	  "package", PACKAGE;
	  "predicate", PREDICATE;
	  "private", PRIVATE;
	  "protected", PROTECTED;
	  "public", PUBLIC;
	  "reads", READS;
	  "real", REAL;
	  "requires", REQUIRES;
	  "rest", REST;
	  "return", RETURN;
	  "short", SHORT;
	  "signals", SIGNALS;
	  "static", STATIC;
	  "super", SUPER;
	  "switch", SWITCH;
	  "synchronized", SYNCHRONIZED;
	  "this", THIS;
	  (* "threadsafe" ? *)
	  "throw", THROW;
	  "throws", THROWS;
	  "transient", TRANSIENT;
	  "true", TRUE;
	  "try", TRY;
	  "var", VAR;
	  "void", VOID;
	  "volatile", VOLATILE;
	  "while", WHILE;	
	]
    in table

  let id_or_kw s =
    try
      let k = Hashtbl.find kw_table s in
      (*i
	prerr_string "Keyword ";
	prerr_endline s;
	i*)
      k
    with
	Not_found ->
	  (*i
	    prerr_string "Ident ";
	    prerr_endline s;
	    i*)
	  (ID s)

  let special_kw_table = 
    let table = Hashtbl.create 17 in
    let _ = 
      List.iter
	(fun (s,t) -> Hashtbl.add table s t)
	[ (* "everything", BSEVERYTHING ; *)
	  "exists", BSEXISTS ;
	  (* "fresh", BSFRESH ; *)
	  "forall", BSFORALL ;
	  "nothing", BSNOTHING;
	  (*
	  "fields_of", BSFIELDSOF;
          "not_conditionally_updated", BSNOTCONDITIONALLYUPDATED;
	  *)
	  "old", BSOLD;
	  "result", BSRESULT;
	  (*"type", BSTYPE;
	  "typeof", BSTYPEOF;
	  "fpi", BSFPI; *)
	]
    in table

  let special_id lexbuf s =
    try
      Hashtbl.find special_kw_table s
    with
	Not_found ->
	  lex_error lexbuf ("unknown special keyword \\"^s)

(*

  let jml_spec_token base jml_string =
(*i
    Format.fprintf Config.log "In file %s, parsing JML Spec: %s@."
      (Location.base_filename base) jml_string;
i*)
    match Jml_syntax.parse_jml_specification base jml_string with 
    | Ast_types.Jml_declaration d -> JML_DECLARATIONS(d)
    | Ast_types.Jml_method_specification s -> JML_METHOD_SPECIFICATION(s)
    | Ast_types.Jml_loop_annotation la -> JML_LOOP_ANNOTATION(la)
    | Ast_types.Jml_assertion a -> JML_ASSERTION(a)
    | Ast_types.Jml_annotation_statement Ast_types.Set_statement s -> JML_ANNOTATION_STATEMENT(Ast_types.Set_statement(s))
    | Ast_types.Jml_axiom(id,e) -> JML_AXIOM(id,e)
    | Ast_types.Jml_type(id) -> JML_TYPE(id)
    | Ast_types.Jml_logic_reads(id,t,p,r) -> JML_LOGIC_READS(id,t,p,r)
    | Ast_types.Jml_logic_def(id,t,p,e) -> JML_LOGIC_DEF(id,t,p,e)
    assert false

*)
  let newline lexbuf =
    let pos = lexbuf.lex_curr_p in
    lexbuf.lex_curr_p <- 
      { pos with pos_lnum = pos.pos_lnum + 1; 
	  pos_bol = pos.pos_cnum }

  let pragma lexbuf id v =
    match id with
      | "ArithOverflow" ->
	  begin
	    match String.lowercase v with	  
	      | "yes" -> Java_options.ignore_overflow := false
	      | "no" -> Java_options.ignore_overflow := true
	      | _ -> lex_error lexbuf "yes or no expected"
	  end  
      | _ -> lex_error lexbuf ("unknown pragma " ^ id)


# 193 "java/java_lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base = 
   "\000\000\185\255\186\255\187\255\188\255\189\255\190\255\191\255\
    \192\255\193\255\004\000\081\000\110\000\078\000\225\255\226\255\
    \003\000\228\255\067\000\081\000\082\000\083\000\107\000\085\000\
    \086\000\108\000\109\000\171\000\245\255\246\255\196\000\254\000\
    \129\000\254\255\003\000\219\255\084\000\139\000\249\255\001\000\
    \141\000\251\255\144\000\113\001\227\001\085\002\115\001\199\002\
    \253\255\120\001\252\255\021\003\096\003\243\255\198\255\186\000\
    \106\003\193\001\217\255\240\255\216\255\239\255\220\255\218\255\
    \212\255\233\255\210\255\232\255\093\000\231\255\111\000\112\000\
    \112\000\230\255\215\255\204\255\211\255\206\255\116\000\214\255\
    \114\000\213\255\212\001\132\003\075\002\161\003\195\003\203\255\
    \202\255\224\003\201\255\199\255\054\002\003\004\200\255\029\004\
    \165\002\039\004\184\002\197\255\141\000\067\004\067\004\142\000\
    \144\000\195\255\137\004\160\004\183\004\146\000\194\255\196\255\
    \016\004\250\255\161\003\064\004\184\004\255\255\253\255\228\001\
    \229\001\140\000\255\003\100\004\140\001\141\000\141\001";
  Lexing.lex_backtrk = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\069\000\052\000\052\000\046\000\255\255\255\255\
    \028\000\255\255\026\000\047\000\034\000\021\000\020\000\019\000\
    \017\000\014\000\013\000\011\000\255\255\255\255\008\000\069\000\
    \018\000\255\255\000\000\255\255\005\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\007\000\057\000\255\255\255\255\255\255\
    \057\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\050\000\255\255\031\000\048\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\032\000\255\255\
    \033\000\255\255\255\255\056\000\255\255\255\255\053\000\255\255\
    \255\255\054\000\255\255\255\255\255\255\056\000\255\255\056\000\
    \255\255\058\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \059\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\004\000\003\000\255\255\255\255\255\255\255\255\
    \002\000\003\000\255\255\003\000\001\000\005\000\255\255";
  Lexing.lex_default = 
   "\002\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\100\000\255\255\255\255\255\255\000\000\000\000\
    \255\255\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\000\000\255\255\255\255\
    \255\255\000\000\255\255\000\000\255\255\039\000\000\000\039\000\
    \042\000\000\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \000\000\042\000\000\000\255\255\255\255\000\000\000\000\255\255\
    \255\255\255\255\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\000\000\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\255\255\000\000\
    \255\255\000\000\255\255\255\255\255\255\255\255\255\255\000\000\
    \000\000\255\255\000\000\000\000\255\255\255\255\000\000\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\000\000\000\000\
    \114\000\000\000\114\000\114\000\118\000\000\000\000\000\120\000\
    \120\000\255\255\123\000\123\000\255\255\255\255\255\255";
  Lexing.lex_trans = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\034\000\033\000\038\000\034\000\034\000\000\000\000\000\
    \034\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \034\000\018\000\003\000\034\000\000\000\023\000\022\000\010\000\
    \009\000\008\000\024\000\026\000\028\000\025\000\027\000\032\000\
    \012\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\014\000\029\000\019\000\020\000\013\000\015\000\
    \076\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\005\000\031\000\004\000\016\000\030\000\
    \101\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\007\000\021\000\006\000\017\000\083\000\
    \075\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\077\000\078\000\070\000\071\000\068\000\
    \066\000\065\000\063\000\062\000\050\000\038\000\082\000\041\000\
    \059\000\061\000\041\000\069\000\083\000\087\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\084\000\084\000\
    \064\000\060\000\058\000\036\000\074\000\072\000\073\000\081\000\
    \037\000\079\000\080\000\082\000\111\000\105\000\082\000\105\000\
    \043\000\110\000\087\000\117\000\117\000\087\000\035\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\085\000\000\000\
    \000\000\000\000\000\000\040\000\000\000\000\000\000\000\067\000\
    \000\000\000\000\000\000\082\000\000\000\000\000\000\000\000\000\
    \000\000\053\000\087\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\057\000\085\000\057\000\
    \000\000\000\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\000\000\000\000\
    \001\000\255\255\000\000\000\000\255\255\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\000\000\
    \000\000\000\000\000\000\030\000\000\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\000\000\000\000\000\000\000\000\051\000\000\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\000\000\043\000\041\000\046\000\041\000\043\000\000\000\
    \046\000\049\000\048\000\000\000\000\000\049\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\000\000\255\255\000\000\000\000\
    \255\255\043\000\000\000\046\000\000\000\126\000\126\000\000\000\
    \049\000\126\000\126\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\000\000\126\000\126\000\000\000\000\000\
    \045\000\000\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\118\000\118\000\000\000\000\000\
    \044\000\000\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\046\000\041\000\033\000\255\255\
    \046\000\056\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\000\000\000\000\000\000\000\000\098\000\
    \000\000\098\000\000\000\046\000\097\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\097\000\097\000\097\000\121\000\255\255\
    \000\000\000\000\000\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\000\000\000\000\000\000\
    \045\000\000\000\000\000\000\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\000\000\000\000\
    \000\000\000\000\044\000\000\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\045\000\041\000\
    \000\000\096\000\045\000\096\000\000\000\000\000\095\000\095\000\
    \095\000\095\000\095\000\095\000\095\000\095\000\095\000\095\000\
    \000\000\255\255\000\000\255\255\000\000\045\000\000\000\000\000\
    \255\255\083\000\000\000\084\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\084\000\084\000\084\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\000\000\
    \082\000\000\000\000\000\000\000\000\000\000\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \082\000\000\000\000\000\000\000\047\000\000\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \049\000\048\000\000\000\000\000\049\000\095\000\095\000\095\000\
    \095\000\095\000\095\000\095\000\095\000\095\000\095\000\000\000\
    \000\000\000\000\000\000\255\255\041\000\255\255\000\000\049\000\
    \097\000\097\000\097\000\097\000\097\000\097\000\097\000\097\000\
    \097\000\097\000\000\000\000\000\000\000\000\000\000\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\000\000\000\000\000\000\000\000\047\000\000\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\000\000\000\000\000\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\255\255\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \000\000\000\000\000\000\000\000\051\000\000\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\054\000\055\000\054\000\000\000\
    \000\000\000\000\000\000\255\255\000\000\000\000\054\000\000\000\
    \054\000\000\000\094\000\000\000\093\000\093\000\093\000\093\000\
    \093\000\093\000\093\000\093\000\093\000\093\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\054\000\055\000\054\000\255\255\
    \091\000\092\000\091\000\000\000\000\000\000\000\054\000\000\000\
    \054\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\089\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \091\000\092\000\091\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\083\000\000\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\084\000\084\000\255\255\000\000\000\000\
    \000\000\000\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \082\000\124\000\000\000\000\000\000\000\000\000\000\000\088\000\
    \089\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\050\000\000\000\000\000\115\000\000\000\000\000\
    \000\000\089\000\089\000\089\000\089\000\089\000\089\000\000\000\
    \082\000\125\000\000\000\000\000\090\000\000\000\113\000\088\000\
    \000\000\000\000\117\000\093\000\093\000\093\000\093\000\093\000\
    \093\000\093\000\093\000\093\000\093\000\000\000\000\000\041\000\
    \000\000\089\000\089\000\089\000\089\000\089\000\089\000\091\000\
    \092\000\091\000\255\255\000\000\090\000\095\000\095\000\095\000\
    \095\000\095\000\095\000\095\000\095\000\095\000\095\000\097\000\
    \097\000\097\000\097\000\097\000\097\000\097\000\097\000\097\000\
    \097\000\091\000\255\255\091\000\000\000\103\000\000\000\091\000\
    \092\000\091\000\104\000\099\000\116\000\099\000\255\255\000\000\
    \000\000\000\000\000\000\106\000\106\000\106\000\106\000\106\000\
    \106\000\106\000\106\000\106\000\106\000\000\000\000\000\000\000\
    \000\000\091\000\000\000\091\000\106\000\106\000\106\000\106\000\
    \106\000\106\000\000\000\099\000\000\000\099\000\255\255\000\000\
    \000\000\000\000\000\000\255\255\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\000\000\000\000\103\000\
    \000\000\255\255\000\000\000\000\255\255\103\000\000\000\000\000\
    \000\000\103\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\103\000\000\000\000\000\000\000\103\000\000\000\103\000\
    \102\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
    \107\000\107\000\107\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\107\000\107\000\107\000\107\000\107\000\107\000\
    \108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
    \108\000\108\000\033\000\000\000\000\000\000\000\000\000\033\000\
    \000\000\108\000\108\000\108\000\108\000\108\000\108\000\109\000\
    \109\000\109\000\109\000\109\000\109\000\109\000\109\000\109\000\
    \109\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \109\000\109\000\109\000\109\000\109\000\109\000\000\000\038\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \113\000\000\000\000\000\000\000\033\000\000\000\000\000\000\000\
    \000\000\000\000\033\000\000\000\000\000\000\000\033\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\033\000\000\000\
    \000\000\000\000\033\000\000\000\033\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \255\255";
  Lexing.lex_check = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\039\000\034\000\000\000\255\255\255\255\
    \034\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\034\000\255\255\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \016\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \010\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\011\000\
    \018\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\013\000\013\000\019\000\019\000\020\000\
    \021\000\022\000\023\000\024\000\036\000\037\000\011\000\040\000\
    \026\000\025\000\042\000\068\000\012\000\011\000\012\000\012\000\
    \012\000\012\000\012\000\012\000\012\000\012\000\012\000\012\000\
    \022\000\025\000\026\000\032\000\070\000\071\000\072\000\080\000\
    \032\000\078\000\078\000\012\000\100\000\103\000\011\000\104\000\
    \040\000\109\000\012\000\121\000\125\000\011\000\032\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\012\000\255\255\
    \255\255\255\255\255\255\037\000\255\255\255\255\255\255\021\000\
    \255\255\255\255\255\255\012\000\255\255\255\255\255\255\255\255\
    \255\255\027\000\012\000\027\000\027\000\027\000\027\000\027\000\
    \027\000\027\000\027\000\027\000\027\000\055\000\012\000\055\000\
    \255\255\255\255\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\255\255\255\255\
    \000\000\039\000\255\255\255\255\010\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\255\255\
    \255\255\255\255\255\255\030\000\255\255\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\255\255\255\255\255\255\255\255\031\000\255\255\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\255\255\043\000\043\000\046\000\046\000\043\000\255\255\
    \046\000\049\000\049\000\255\255\255\255\049\000\255\255\255\255\
    \255\255\255\255\255\255\037\000\255\255\040\000\255\255\255\255\
    \042\000\043\000\255\255\046\000\255\255\124\000\126\000\255\255\
    \049\000\124\000\126\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\255\255\124\000\126\000\255\255\255\255\
    \046\000\255\255\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\124\000\126\000\255\255\255\255\
    \043\000\255\255\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\044\000\044\000\119\000\120\000\
    \044\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\255\255\255\255\255\255\255\255\082\000\
    \255\255\082\000\255\255\044\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\082\000\119\000\120\000\
    \255\255\255\255\255\255\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\255\255\255\255\255\255\
    \044\000\255\255\255\255\255\255\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\255\255\255\255\
    \255\255\255\255\044\000\255\255\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\045\000\045\000\
    \255\255\092\000\045\000\092\000\255\255\255\255\092\000\092\000\
    \092\000\092\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \255\255\043\000\255\255\046\000\255\255\045\000\255\255\255\255\
    \049\000\084\000\255\255\084\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\084\000\084\000\084\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\255\255\
    \084\000\255\255\255\255\255\255\255\255\255\255\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \084\000\255\255\255\255\255\255\045\000\255\255\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \047\000\047\000\255\255\255\255\047\000\096\000\096\000\096\000\
    \096\000\096\000\096\000\096\000\096\000\096\000\096\000\255\255\
    \255\255\255\255\255\255\044\000\119\000\120\000\255\255\047\000\
    \098\000\098\000\098\000\098\000\098\000\098\000\098\000\098\000\
    \098\000\098\000\255\255\255\255\255\255\255\255\255\255\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\255\255\255\255\255\255\255\255\047\000\255\255\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\255\255\255\255\255\255\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\045\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \255\255\255\255\255\255\255\255\051\000\255\255\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\052\000\052\000\052\000\255\255\
    \255\255\255\255\255\255\114\000\255\255\255\255\056\000\255\255\
    \056\000\255\255\083\000\255\255\083\000\083\000\083\000\083\000\
    \083\000\083\000\083\000\083\000\083\000\083\000\255\255\255\255\
    \255\255\255\255\255\255\114\000\052\000\052\000\052\000\047\000\
    \083\000\083\000\083\000\255\255\255\255\255\255\056\000\255\255\
    \056\000\085\000\085\000\085\000\085\000\085\000\085\000\085\000\
    \085\000\085\000\085\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\085\000\085\000\085\000\085\000\085\000\085\000\
    \083\000\083\000\083\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\086\000\255\255\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\114\000\255\255\255\255\
    \255\255\255\255\085\000\085\000\085\000\085\000\085\000\085\000\
    \086\000\122\000\255\255\255\255\255\255\255\255\255\255\086\000\
    \089\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\112\000\255\255\255\255\112\000\255\255\255\255\
    \255\255\089\000\089\000\089\000\089\000\089\000\089\000\255\255\
    \086\000\122\000\255\255\255\255\089\000\255\255\122\000\086\000\
    \255\255\255\255\112\000\093\000\093\000\093\000\093\000\093\000\
    \093\000\093\000\093\000\093\000\093\000\255\255\255\255\122\000\
    \255\255\089\000\089\000\089\000\089\000\089\000\089\000\093\000\
    \093\000\093\000\115\000\255\255\089\000\095\000\095\000\095\000\
    \095\000\095\000\095\000\095\000\095\000\095\000\095\000\097\000\
    \097\000\097\000\097\000\097\000\097\000\097\000\097\000\097\000\
    \097\000\095\000\115\000\095\000\255\255\101\000\255\255\093\000\
    \093\000\093\000\101\000\097\000\112\000\097\000\123\000\255\255\
    \255\255\255\255\255\255\102\000\102\000\102\000\102\000\102\000\
    \102\000\102\000\102\000\102\000\102\000\255\255\255\255\255\255\
    \255\255\095\000\255\255\095\000\102\000\102\000\102\000\102\000\
    \102\000\102\000\255\255\097\000\255\255\097\000\123\000\255\255\
    \255\255\255\255\255\255\123\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\115\000\255\255\255\255\101\000\
    \255\255\114\000\255\255\255\255\123\000\101\000\255\255\255\255\
    \255\255\101\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\101\000\255\255\255\255\255\255\101\000\255\255\101\000\
    \101\000\106\000\106\000\106\000\106\000\106\000\106\000\106\000\
    \106\000\106\000\106\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\106\000\106\000\106\000\106\000\106\000\106\000\
    \107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
    \107\000\107\000\116\000\255\255\255\255\255\255\255\255\116\000\
    \255\255\107\000\107\000\107\000\107\000\107\000\107\000\108\000\
    \108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
    \108\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \108\000\108\000\108\000\108\000\108\000\108\000\255\255\122\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \112\000\255\255\255\255\255\255\116\000\255\255\255\255\255\255\
    \255\255\255\255\116\000\255\255\255\255\255\255\116\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\116\000\255\255\
    \255\255\255\255\116\000\255\255\116\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \115\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\123\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \116\000";
  Lexing.lex_base_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\075\000\189\000\000\000\008\001\
    \013\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_backtrk_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_default_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_trans_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\001\000\000\000\000\000\000\000\001\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\001\000\000\000\000\000\000\000\000\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\000\000\000\000\000\000\007\000\000\000\000\000\
    \000\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\000\000\000\000\000\000\000\000\004\000\
    \000\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\000\000\000\000\000\000\
    \007\000\000\000\000\000\000\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\000\000\000\000\
    \000\000\000\000\004\000\000\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\007\000\000\000\
    \000\000\000\000\007\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\007\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \000\000\000\000\000\000\000\000\010\000\000\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\000\000\000\000\000\000\000\000\010\000\
    \000\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000";
  Lexing.lex_check_code = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\043\000\255\255\255\255\255\255\043\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \043\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\040\000\255\255\255\255\255\255\255\255\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\255\255\255\255\255\255\046\000\255\255\255\255\
    \255\255\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\255\255\255\255\255\255\255\255\043\000\
    \255\255\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\255\255\255\255\255\255\
    \044\000\255\255\255\255\255\255\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\255\255\255\255\
    \255\255\255\255\044\000\255\255\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
    \044\000\044\000\044\000\044\000\044\000\044\000\045\000\255\255\
    \255\255\255\255\045\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\045\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \255\255\255\255\255\255\255\255\045\000\255\255\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\255\255\255\255\255\255\255\255\047\000\
    \255\255\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255";
  Lexing.lex_code = 
   "\255\004\255\255\005\255\255\006\255\255\007\255\255\002\006\003\
    \007\000\004\001\005\255";
}

let rec token lexbuf =
  lexbuf.Lexing.lex_mem <- Array.create 8 (-1) ;   __ocaml_lex_token_rec lexbuf 0
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 243 "java/java_lexer.mll"
      ( token lexbuf )
# 813 "java/java_lexer.ml"

  | 1 ->
# 245 "java/java_lexer.mll"
      ( newline lexbuf; token lexbuf )
# 818 "java/java_lexer.ml"

  | 2 ->
let
# 246 "java/java_lexer.mll"
                                 id
# 824 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_mem.(1)
and
# 247 "java/java_lexer.mll"
                              v
# 829 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(2) lexbuf.Lexing.lex_mem.(3) in
# 248 "java/java_lexer.mll"
      ( pragma lexbuf id v; newline lexbuf; token lexbuf )
# 833 "java/java_lexer.ml"

  | 3 ->
# 250 "java/java_lexer.mll"
      ( let loc = lexeme_start_p lexbuf in
	Buffer.clear buf; ANNOT(loc, annot lexbuf) )
# 839 "java/java_lexer.ml"

  | 4 ->
let
# 252 "java/java_lexer.mll"
                        a
# 845 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf (lexbuf.Lexing.lex_start_pos + 3) (lexbuf.Lexing.lex_curr_pos + -1) in
# 253 "java/java_lexer.mll"
      ( let loc = lexeme_start_p lexbuf in
	newline lexbuf;	ANNOT(loc,a) )
# 850 "java/java_lexer.ml"

  | 5 ->
# 256 "java/java_lexer.mll"
      ( comment lexbuf; token lexbuf )
# 855 "java/java_lexer.ml"

  | 6 ->
# 258 "java/java_lexer.mll"
      ( newline lexbuf; token lexbuf )
# 860 "java/java_lexer.ml"

  | 7 ->
let
# 259 "java/java_lexer.mll"
                                                            id
# 866 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf (lexbuf.Lexing.lex_start_pos + 1) lexbuf.Lexing.lex_curr_pos in
# 260 "java/java_lexer.mll"
      ( special_id lexbuf id )
# 870 "java/java_lexer.ml"

  | 8 ->
let
# 261 "java/java_lexer.mll"
                                                      id
# 876 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 262 "java/java_lexer.mll"
      ( id_or_kw id )
# 880 "java/java_lexer.ml"

  | 9 ->
# 264 "java/java_lexer.mll"
      ( SEMICOLON )
# 885 "java/java_lexer.ml"

  | 10 ->
# 266 "java/java_lexer.mll"
      ( COMMA )
# 890 "java/java_lexer.ml"

  | 11 ->
# 268 "java/java_lexer.mll"
      ( DOT )
# 895 "java/java_lexer.ml"

  | 12 ->
# 270 "java/java_lexer.mll"
      ( DOTDOT )
# 900 "java/java_lexer.ml"

  | 13 ->
# 272 "java/java_lexer.mll"
      ( PLUS )
# 905 "java/java_lexer.ml"

  | 14 ->
# 274 "java/java_lexer.mll"
      ( MINUS )
# 910 "java/java_lexer.ml"

  | 15 ->
# 276 "java/java_lexer.mll"
      ( PLUSPLUS )
# 915 "java/java_lexer.ml"

  | 16 ->
# 278 "java/java_lexer.mll"
      ( MINUSMINUS )
# 920 "java/java_lexer.ml"

  | 17 ->
# 280 "java/java_lexer.mll"
      ( STAR )
# 925 "java/java_lexer.ml"

  | 18 ->
# 282 "java/java_lexer.mll"
      ( SLASH )
# 930 "java/java_lexer.ml"

  | 19 ->
# 284 "java/java_lexer.mll"
      ( PERCENT )
# 935 "java/java_lexer.ml"

  | 20 ->
# 286 "java/java_lexer.mll"
      ( AMPERSAND )
# 940 "java/java_lexer.ml"

  | 21 ->
# 288 "java/java_lexer.mll"
      ( VERTICALBAR )
# 945 "java/java_lexer.ml"

  | 22 ->
# 290 "java/java_lexer.mll"
      ( AMPERSANDAMPERSAND )
# 950 "java/java_lexer.ml"

  | 23 ->
# 292 "java/java_lexer.mll"
      ( VERTICALBARVERTICALBAR )
# 955 "java/java_lexer.ml"

  | 24 ->
# 294 "java/java_lexer.mll"
      ( EQEQGT )
# 960 "java/java_lexer.ml"

  | 25 ->
# 296 "java/java_lexer.mll"
      ( LTEQEQGT )
# 965 "java/java_lexer.ml"

  | 26 ->
# 298 "java/java_lexer.mll"
      ( BANG )
# 970 "java/java_lexer.ml"

  | 27 ->
# 300 "java/java_lexer.mll"
      ( TILDA )
# 975 "java/java_lexer.ml"

  | 28 ->
# 302 "java/java_lexer.mll"
      ( CARET )
# 980 "java/java_lexer.ml"

  | 29 ->
# 304 "java/java_lexer.mll"
      ( QUESTIONMARK )
# 985 "java/java_lexer.ml"

  | 30 ->
# 306 "java/java_lexer.mll"
      ( COLON )
# 990 "java/java_lexer.ml"

  | 31 ->
# 308 "java/java_lexer.mll"
      ( SHIFT Blsl )
# 995 "java/java_lexer.ml"

  | 32 ->
# 310 "java/java_lexer.mll"
      ( SHIFT Blsr )
# 1000 "java/java_lexer.ml"

  | 33 ->
# 312 "java/java_lexer.mll"
      ( SHIFT Basr )
# 1005 "java/java_lexer.ml"

  | 34 ->
# 314 "java/java_lexer.mll"
      ( EQ )
# 1010 "java/java_lexer.ml"

  | 35 ->
# 316 "java/java_lexer.mll"
      ( ASSIGNOP Bmul )
# 1015 "java/java_lexer.ml"

  | 36 ->
# 318 "java/java_lexer.mll"
      ( ASSIGNOP Bdiv )
# 1020 "java/java_lexer.ml"

  | 37 ->
# 320 "java/java_lexer.mll"
      ( ASSIGNOP Bmod )
# 1025 "java/java_lexer.ml"

  | 38 ->
# 322 "java/java_lexer.mll"
      ( ASSIGNOP Badd )
# 1030 "java/java_lexer.ml"

  | 39 ->
# 324 "java/java_lexer.mll"
      ( ASSIGNOP Bsub )
# 1035 "java/java_lexer.ml"

  | 40 ->
# 326 "java/java_lexer.mll"
      ( ASSIGNOP Blsl )
# 1040 "java/java_lexer.ml"

  | 41 ->
# 328 "java/java_lexer.mll"
      ( ASSIGNOP Blsr )
# 1045 "java/java_lexer.ml"

  | 42 ->
# 330 "java/java_lexer.mll"
      ( ASSIGNOP Basr )
# 1050 "java/java_lexer.ml"

  | 43 ->
# 332 "java/java_lexer.mll"
      ( ASSIGNOP Bbwand )
# 1055 "java/java_lexer.ml"

  | 44 ->
# 334 "java/java_lexer.mll"
      ( ASSIGNOP Bbwxor )
# 1060 "java/java_lexer.ml"

  | 45 ->
# 336 "java/java_lexer.mll"
      ( ASSIGNOP Bbwor )
# 1065 "java/java_lexer.ml"

  | 46 ->
# 338 "java/java_lexer.mll"
      ( COMP Bgt )
# 1070 "java/java_lexer.ml"

  | 47 ->
# 340 "java/java_lexer.mll"
      ( COMP Blt )
# 1075 "java/java_lexer.ml"

  | 48 ->
# 342 "java/java_lexer.mll"
      ( COMP Ble )
# 1080 "java/java_lexer.ml"

  | 49 ->
# 344 "java/java_lexer.mll"
      ( COMP Bge )
# 1085 "java/java_lexer.ml"

  | 50 ->
# 346 "java/java_lexer.mll"
      ( EQOP Beq )
# 1090 "java/java_lexer.ml"

  | 51 ->
# 348 "java/java_lexer.mll"
      ( EQOP Bne )
# 1095 "java/java_lexer.ml"

  | 52 ->
let
# 352 "java/java_lexer.mll"
                                      n
# 1101 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 353 "java/java_lexer.mll"
      ( INTCONSTANT n )
# 1105 "java/java_lexer.ml"

  | 53 ->
let
# 357 "java/java_lexer.mll"
                               n
# 1111 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 358 "java/java_lexer.mll"
      ( INTCONSTANT n )
# 1115 "java/java_lexer.ml"

  | 54 ->
let
# 362 "java/java_lexer.mll"
                                                      n
# 1121 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 363 "java/java_lexer.mll"
    ( INTCONSTANT n )
# 1125 "java/java_lexer.ml"

  | 55 ->
let
# 367 "java/java_lexer.mll"
            n
# 1131 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_curr_pos + -2) in
# 367 "java/java_lexer.mll"
                            ( raise (Dotdot n) )
# 1135 "java/java_lexer.ml"

  | 56 ->
# 372 "java/java_lexer.mll"
      ( REALCONSTANT (lexeme lexbuf) )
# 1140 "java/java_lexer.ml"

  | 57 ->
# 375 "java/java_lexer.mll"
      ( REALCONSTANT (lexeme lexbuf) )
# 1145 "java/java_lexer.ml"

  | 58 ->
# 378 "java/java_lexer.mll"
      ( REALCONSTANT (lexeme lexbuf) )
# 1150 "java/java_lexer.ml"

  | 59 ->
let
# 382 "java/java_lexer.mll"
                 s
# 1156 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 3) in
# 383 "java/java_lexer.mll"
      ( CHARACTER s )
# 1160 "java/java_lexer.ml"

  | 60 ->
let
# 385 "java/java_lexer.mll"
                                   s
# 1166 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 4) in
# 386 "java/java_lexer.mll"
      ( CHARACTER s )
# 1170 "java/java_lexer.ml"

  | 61 ->
let
# 389 "java/java_lexer.mll"
                                               s
# 1176 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 8) in
# 390 "java/java_lexer.mll"
      ( CHARACTER s )
# 1180 "java/java_lexer.ml"

  | 62 ->
# 393 "java/java_lexer.mll"
      ( LEFTPAR )
# 1185 "java/java_lexer.ml"

  | 63 ->
# 395 "java/java_lexer.mll"
      ( RIGHTPAR )
# 1190 "java/java_lexer.ml"

  | 64 ->
# 397 "java/java_lexer.mll"
      ( LEFTBRACE )
# 1195 "java/java_lexer.ml"

  | 65 ->
# 399 "java/java_lexer.mll"
      ( RIGHTBRACE )
# 1200 "java/java_lexer.ml"

  | 66 ->
# 401 "java/java_lexer.mll"
      ( LEFTBRACKET )
# 1205 "java/java_lexer.ml"

  | 67 ->
# 403 "java/java_lexer.mll"
      ( RIGHTBRACKET )
# 1210 "java/java_lexer.ml"

  | 68 ->
# 405 "java/java_lexer.mll"
      ( Buffer.clear buf; STRING(string lexbuf) )
# 1215 "java/java_lexer.ml"

  | 69 ->
# 407 "java/java_lexer.mll"
      ( lex_error lexbuf ("unexpected char `" ^ lexeme lexbuf ^ "'") )
# 1220 "java/java_lexer.ml"

  | 70 ->
# 409 "java/java_lexer.mll"
      ( EOF )
# 1225 "java/java_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_token_rec lexbuf __ocaml_lex_state

and string lexbuf =
    __ocaml_lex_string_rec lexbuf 112
and __ocaml_lex_string_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 413 "java/java_lexer.mll"
      ( Buffer.contents buf )
# 1236 "java/java_lexer.ml"

  | 1 ->
# 415 "java/java_lexer.mll"
      ( Buffer.add_string buf (lexeme lexbuf);
	string lexbuf )
# 1242 "java/java_lexer.ml"

  | 2 ->
# 418 "java/java_lexer.mll"
      ( lex_error lexbuf "unknown escape sequence in string" )
# 1247 "java/java_lexer.ml"

  | 3 ->
# 420 "java/java_lexer.mll"
      ( (* no \n anymore in strings since java 1.4 *)
	lex_error lexbuf "string not terminated"; )
# 1253 "java/java_lexer.ml"

  | 4 ->
# 423 "java/java_lexer.mll"
      ( Buffer.add_string buf (lexeme lexbuf); string lexbuf )
# 1258 "java/java_lexer.ml"

  | 5 ->
# 425 "java/java_lexer.mll"
      ( lex_error lexbuf "string not terminated" )
# 1263 "java/java_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_string_rec lexbuf __ocaml_lex_state

and comment lexbuf =
    __ocaml_lex_comment_rec lexbuf 119
and __ocaml_lex_comment_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 429 "java/java_lexer.mll"
      ( () )
# 1274 "java/java_lexer.ml"

  | 1 ->
# 431 "java/java_lexer.mll"
      ( newline lexbuf; comment lexbuf )
# 1279 "java/java_lexer.ml"

  | 2 ->
# 433 "java/java_lexer.mll"
      ( comment lexbuf )
# 1284 "java/java_lexer.ml"

  | 3 ->
# 435 "java/java_lexer.mll"
      ( comment lexbuf )
# 1289 "java/java_lexer.ml"

  | 4 ->
# 437 "java/java_lexer.mll"
      ( lex_error lexbuf "comment not terminated" )
# 1294 "java/java_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_comment_rec lexbuf __ocaml_lex_state

and annot lexbuf =
    __ocaml_lex_annot_rec lexbuf 122
and __ocaml_lex_annot_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 441 "java/java_lexer.mll"
      ( Buffer.contents buf )
# 1305 "java/java_lexer.ml"

  | 1 ->
# 443 "java/java_lexer.mll"
      ( newline lexbuf;  
	Buffer.add_string buf (lexeme lexbuf);
	annot lexbuf )
# 1312 "java/java_lexer.ml"

  | 2 ->
let
# 446 "java/java_lexer.mll"
                    s
# 1318 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_curr_pos + -1) in
# 447 "java/java_lexer.mll"
      ( newline lexbuf;  
	Buffer.add_string buf s;
	Buffer.add_char buf ' ';
	annot lexbuf )
# 1325 "java/java_lexer.ml"

  | 3 ->
# 452 "java/java_lexer.mll"
      ( Buffer.add_string buf (lexeme lexbuf);
	annot lexbuf )
# 1331 "java/java_lexer.ml"

  | 4 ->
# 455 "java/java_lexer.mll"
      ( annot lexbuf )
# 1336 "java/java_lexer.ml"

  | 5 ->
# 457 "java/java_lexer.mll"
      ( Buffer.add_string buf (lexeme lexbuf);
	annot lexbuf )
# 1342 "java/java_lexer.ml"

  | 6 ->
# 460 "java/java_lexer.mll"
      ( lex_error lexbuf "annotation not terminated" )
# 1347 "java/java_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_annot_rec lexbuf __ocaml_lex_state

;;

# 462 "java/java_lexer.mll"
 

let dotdot_mem = ref false
 
let next_token lexbuf =
  if !dotdot_mem then
    begin
      dotdot_mem := false;
      Format.eprintf "DOTDOT@.";
      DOTDOT
    end
  else
    begin
      try
	token lexbuf
      with
	Dotdot(n) ->
	  dotdot_mem := true;
	  INTCONSTANT n
    end

  let parse f c =
    let lb = from_channel c in
    lb.lex_curr_p <- { lb.lex_curr_p with pos_fname = f };
    try
      Java_parser.compilation_unit next_token lb
    with Parsing.Parse_error ->
      Java_options.parsing_error (loc lb) ""


# 1384 "java/java_lexer.ml"
