# 28 "mix/mix_lexer.mll"
 
  open Lexing 
  open Mix_ast
  open Mix_parser

  let keywords = Hashtbl.create 97
  let () = 
    List.iter 
      (fun (x,y) -> Hashtbl.add keywords x y)
      [ (* loading *)
	"lda", INSTR (Ld A);  "ldx", INSTR (Ld X);
	"ld1", INSTR (Ld I1); "ld2", INSTR (Ld I2); "ld3", INSTR (Ld I3);
	"ld4", INSTR (Ld I4); "ld5", INSTR (Ld I5); "ld6", INSTR (Ld I6);
	"ldan", INSTR (Ldn A);  "ldxn", INSTR (Ldn X);
	"ld1n", INSTR (Ldn I1); "ld2n", INSTR (Ldn I2); "ld3n", INSTR (Ldn I3);
	"ld4n", INSTR (Ldn I4); "ld5n", INSTR (Ldn I5); "ld6n", INSTR (Ldn I6);
	(* storing *)
	"sta", INSTR (St A);  "stx", INSTR (St X);
	"st1", INSTR (St I1); "st2", INSTR (St I2); "st3", INSTR (St I3);
	"st4", INSTR (St I4); "st5", INSTR (St I5); "st6", INSTR (St I6);
	"stj", INSTR Stj;     "stz", INSTR Stz;
	(* arithmetic *)
	"add", INSTR Add; "sub", INSTR Sub; 
	"mul", INSTR Mul; "div", INSTR Div;
	"srb", INSTR Srb;
	(* address transfer *)
	"enta", INSTR (Ent A);  "entx", INSTR (Ent X);
	"ent1", INSTR (Ent I1); "ent2", INSTR (Ent I2); "ent3", INSTR (Ent I3);
	"ent4", INSTR (Ent I4); "ent5", INSTR (Ent I5); "ent6", INSTR (Ent I6);
	"enna", INSTR (Enn A);  "ennx", INSTR (Enn X);
	"enn1", INSTR (Enn I1); "enn2", INSTR (Enn I2); "enn3", INSTR (Enn I3);
	"enn4", INSTR (Enn I4); "enn5", INSTR (Enn I5); "enn6", INSTR (Enn I6);
	"inca", INSTR (Inc A);  "incx", INSTR (Inc X);
	"inc1", INSTR (Inc I1); "inc2", INSTR (Inc I2); "inc3", INSTR (Inc I3);
	"inc4", INSTR (Inc I4); "inc5", INSTR (Inc I5); "inc6", INSTR (Inc I6);
	"deca", INSTR (Dec A);  "decx", INSTR (Dec X);
	"dec1", INSTR (Dec I1); "dec2", INSTR (Dec I2); "dec3", INSTR (Dec I3);
	"dec4", INSTR (Dec I4); "dec5", INSTR (Dec I5); "dec6", INSTR (Dec I6);
        (* comparison *)
	"cmpa", INSTR (Cmp A);  "cmpx", INSTR (Cmp X);
	"cmp1", INSTR (Cmp I1); "cmp2", INSTR (Cmp I2); "cmp3", INSTR (Cmp I3);
	"cmp4", INSTR (Cmp I4); "cmp5", INSTR (Cmp I5); "cmp6", INSTR (Cmp I6);
	(* jumps *)
	"jmp", INSTR Jmp; "jsj", INSTR Jsj; "jl", INSTR Jl;
	"jg", INSTR Jg; "jge", INSTR Jge; "je", INSTR Je; "jne", INSTR Jne;
	"jan", INSTR (Jn A);  "jxn", INSTR (Jn X);
	"j1n", INSTR (Jn I1); "j2n", INSTR (Jn I2); "j3n", INSTR (Jn I3);
	"j4n", INSTR (Jn I4); "j5n", INSTR (Jn I5); "j6n", INSTR (Jn I6);
	"jaz", INSTR (Jz A);  "jxz", INSTR (Jz X);
	"j1z", INSTR (Jz I1); "j2z", INSTR (Jz I2); "j3z", INSTR (Jz I3);
	"j4z", INSTR (Jz I4); "j5z", INSTR (Jz I5); "j6z", INSTR (Jz I6);
	"jap", INSTR (Jp A);  "jxp", INSTR (Jp X);
	"j1p", INSTR (Jp I1); "j2p", INSTR (Jp I2); "j3p", INSTR (Jp I3);
	"j4p", INSTR (Jp I4); "j5p", INSTR (Jp I5); "j6p", INSTR (Jp I6);
	"jann", INSTR (Jnn A);  "jxnn", INSTR (Jnn X);
	"j1nn", INSTR (Jnn I1); "j2nn", INSTR (Jnn I2); "j3nn", INSTR (Jnn I3);
	"j4nn", INSTR (Jnn I4); "j5nn", INSTR (Jnn I5); "j6nn", INSTR (Jnn I6);
	"janz", INSTR (Jnz A);  "jxnz", INSTR (Jnz X);
	"j1nz", INSTR (Jnz I1); "j2nz", INSTR (Jnz I2); "j3nz", INSTR (Jnz I3);
	"j4nz", INSTR (Jnz I4); "j5nz", INSTR (Jnz I5); "j6nz", INSTR (Jnz I6);
	"janp", INSTR (Jnp A);  "jxnp", INSTR (Jnp X);
	"j1np", INSTR (Jnp I1); "j2np", INSTR (Jnp I2); "j3np", INSTR (Jnp I3);
	"j4np", INSTR (Jnp I4); "j5np", INSTR (Jnp I5); "j6np", INSTR (Jnp I6);
	(* other *)
	"nop", INSTR Nop;
	"hlt", INSTR Hlt;
	(* pseudo *)
	"equ", EQU;
	"orig", ORIG;
      ]

  let newline lexbuf =
    let pos = lexbuf.lex_curr_p in
    lexbuf.lex_curr_p <- 
      { pos with pos_lnum = pos.pos_lnum + 1; pos_bol = pos.pos_cnum }

  let string_buf = Buffer.create 1024

  let char_for_backslash = function
    | 'n' -> '\n'
    | 't' -> '\t'
    | c -> c

  exception Lexical_error of string

  (* local symbols *)

  let local_symbols = Array.create 10 (0,0)

  let make_local_symbol i n = Printf.sprintf "local_symbol_%d_%d" i n

  let line lexbuf = (lexeme_start_p lexbuf).pos_lnum

  let local_symbol lexbuf i =
    let (n,_) = local_symbols.(i) in
    local_symbols.(i) <- (n+1, line lexbuf);
    make_local_symbol i (n+1)

  let forward_local_symbol _ i =
    let (n,_) = local_symbols.(i) in
    make_local_symbol i (n+1)

  let backward_local_symbol lexbuf i =
    let (n,l) = local_symbols.(i) in
    make_local_symbol i (if line lexbuf > l then n else n-1)


# 110 "mix/mix_lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base = 
   "\000\000\234\255\235\255\236\255\237\255\238\255\239\255\240\255\
    \241\255\242\255\243\255\004\000\001\000\077\000\102\000\003\000\
    \255\255\252\255\177\000\249\255\250\255\001\000\251\255\012\000\
    \247\255\039\000\245\255\246\255\151\000\253\255\018\000\014\000\
    \254\255\004\000\001\000\012\000\013\000\014\000\130\000\020\000\
    \017\000\016\000\152\000\022\000\044\000";
  Lexing.lex_backtrk = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\021\000\010\000\007\000\002\000\001\000\
    \255\255\255\255\007\000\255\255\255\255\255\255\255\255\009\000\
    \255\255\011\000\255\255\255\255\255\255\255\255\004\000\004\000\
    \255\255\255\255\004\000\255\255\003\000\255\255\255\255\003\000\
    \003\000\255\255\255\255\003\000\255\255";
  Lexing.lex_default = 
   "\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\255\255\000\000\000\000\255\255\000\000\255\255\
    \000\000\255\255\000\000\000\000\022\000\000\000\255\255\255\255\
    \000\000\022\000\032\000\017\000\255\255\255\255\017\000\255\255\
    \255\255\255\255\017\000\255\255\255\255";
  Lexing.lex_trans = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\015\000\016\000\000\000\015\000\015\000\029\000\000\000\
    \015\000\000\000\000\000\000\000\000\000\000\000\029\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \015\000\000\000\010\000\015\000\000\000\000\000\016\000\000\000\
    \007\000\006\000\003\000\005\000\009\000\004\000\025\000\011\000\
    \013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\
    \013\000\013\000\008\000\022\000\032\000\016\000\041\000\016\000\
    \044\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\016\000\000\000\000\000\000\000\014\000\
    \034\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\012\000\023\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\024\000\
    \026\000\036\000\037\000\016\000\029\000\014\000\016\000\019\000\
    \027\000\000\000\000\000\020\000\000\000\021\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \017\000\029\000\029\000\000\000\000\000\000\000\000\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\031\000\000\000\000\000\000\000\014\000\030\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\039\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\043\000\000\000\000\000\000\000\000\000\000\000\040\000\
    \002\000\255\255\000\000\000\000\017\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\032\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\016\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\032\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\017\000\
    \032\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000";
  Lexing.lex_check = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\255\255\015\000\000\000\033\000\255\255\
    \015\000\255\255\255\255\255\255\255\255\255\255\035\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\000\000\015\000\255\255\255\255\033\000\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\011\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\021\000\030\000\031\000\039\000\041\000\
    \043\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\044\000\255\255\255\255\255\255\000\000\
    \033\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\012\000\013\000\013\000\013\000\
    \013\000\013\000\013\000\013\000\013\000\013\000\013\000\023\000\
    \025\000\035\000\036\000\037\000\038\000\014\000\040\000\013\000\
    \025\000\255\255\255\255\013\000\255\255\013\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\028\000\042\000\255\255\255\255\255\255\255\255\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\028\000\255\255\255\255\255\255\014\000\028\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\038\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\042\000\255\255\255\255\255\255\255\255\255\255\038\000\
    \000\000\034\000\255\255\255\255\033\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\035\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\042\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\038\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\028\000\
    \042\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255";
  Lexing.lex_base_code = 
   "";
  Lexing.lex_backtrk_code = 
   "";
  Lexing.lex_default_code = 
   "";
  Lexing.lex_trans_code = 
   "";
  Lexing.lex_check_code = 
   "";
  Lexing.lex_code = 
   "";
}

let rec token lexbuf =
    __ocaml_lex_token_rec lexbuf 0
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 146 "mix/mix_lexer.mll"
      ( newline lexbuf; token lexbuf )
# 266 "mix/mix_lexer.ml"

  | 1 ->
# 148 "mix/mix_lexer.mll"
      ( token lexbuf )
# 271 "mix/mix_lexer.ml"

  | 2 ->
let
# 149 "mix/mix_lexer.mll"
             id
# 277 "mix/mix_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 150 "mix/mix_lexer.mll"
      ( let lid = String.lowercase id in
	try Hashtbl.find keywords lid with Not_found -> IDENT id )
# 282 "mix/mix_lexer.ml"

  | 3 ->
let
# 152 "mix/mix_lexer.mll"
             id
# 288 "mix/mix_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_curr_pos + -1) in
# 153 "mix/mix_lexer.mll"
      ( LABEL id )
# 292 "mix/mix_lexer.ml"

  | 4 ->
let
# 154 "mix/mix_lexer.mll"
             d
# 298 "mix/mix_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 155 "mix/mix_lexer.mll"
      ( LABEL (local_symbol lexbuf (Char.code d - Char.code '0')) )
# 302 "mix/mix_lexer.ml"

  | 5 ->
let
# 156 "mix/mix_lexer.mll"
             d
# 308 "mix/mix_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 157 "mix/mix_lexer.mll"
      ( IDENT (forward_local_symbol lexbuf (Char.code d - Char.code '0')) )
# 312 "mix/mix_lexer.ml"

  | 6 ->
let
# 158 "mix/mix_lexer.mll"
             d
# 318 "mix/mix_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 159 "mix/mix_lexer.mll"
      ( IDENT (backward_local_symbol lexbuf (Char.code d - Char.code '0')) )
# 322 "mix/mix_lexer.ml"

  | 7 ->
let
# 160 "mix/mix_lexer.mll"
               n
# 328 "mix/mix_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 161 "mix/mix_lexer.mll"
      ( INTEGER n )
# 332 "mix/mix_lexer.ml"

  | 8 ->
# 163 "mix/mix_lexer.mll"
      ( Buffer.clear string_buf; verbatim lexbuf )
# 337 "mix/mix_lexer.ml"

  | 9 ->
# 165 "mix/mix_lexer.mll"
      ( Buffer.clear string_buf; invariant lexbuf )
# 342 "mix/mix_lexer.ml"

  | 10 ->
# 167 "mix/mix_lexer.mll"
      ( Buffer.clear string_buf; assertion lexbuf )
# 347 "mix/mix_lexer.ml"

  | 11 ->
# 169 "mix/mix_lexer.mll"
      ( comment lexbuf; token lexbuf )
# 352 "mix/mix_lexer.ml"

  | 12 ->
# 170 "mix/mix_lexer.mll"
              ( Buffer.clear string_buf; string lexbuf )
# 357 "mix/mix_lexer.ml"

  | 13 ->
# 172 "mix/mix_lexer.mll"
      ( COMMA )
# 362 "mix/mix_lexer.ml"

  | 14 ->
# 174 "mix/mix_lexer.mll"
      ( COLON )
# 367 "mix/mix_lexer.ml"

  | 15 ->
# 176 "mix/mix_lexer.mll"
      ( LPAR )
# 372 "mix/mix_lexer.ml"

  | 16 ->
# 178 "mix/mix_lexer.mll"
      ( RPAR )
# 377 "mix/mix_lexer.ml"

  | 17 ->
# 180 "mix/mix_lexer.mll"
      ( PLUS )
# 382 "mix/mix_lexer.ml"

  | 18 ->
# 182 "mix/mix_lexer.mll"
      ( MINUS )
# 387 "mix/mix_lexer.ml"

  | 19 ->
# 184 "mix/mix_lexer.mll"
      ( STAR )
# 392 "mix/mix_lexer.ml"

  | 20 ->
# 186 "mix/mix_lexer.mll"
      ( EOF )
# 397 "mix/mix_lexer.ml"

  | 21 ->
let
# 187 "mix/mix_lexer.mll"
         c
# 403 "mix/mix_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 188 "mix/mix_lexer.mll"
      ( raise (Lexical_error ("illegal character: " ^ String.make 1 c)) )
# 407 "mix/mix_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_token_rec lexbuf __ocaml_lex_state

and comment lexbuf =
    __ocaml_lex_comment_rec lexbuf 28
and __ocaml_lex_comment_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 192 "mix/mix_lexer.mll"
      ( () )
# 418 "mix/mix_lexer.ml"

  | 1 ->
# 194 "mix/mix_lexer.mll"
      ( comment lexbuf; comment lexbuf )
# 423 "mix/mix_lexer.ml"

  | 2 ->
# 196 "mix/mix_lexer.mll"
      ( newline lexbuf; comment lexbuf )
# 428 "mix/mix_lexer.ml"

  | 3 ->
# 198 "mix/mix_lexer.mll"
      ( raise (Lexical_error "unterminated comment") )
# 433 "mix/mix_lexer.ml"

  | 4 ->
# 200 "mix/mix_lexer.mll"
      ( comment lexbuf )
# 438 "mix/mix_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_comment_rec lexbuf __ocaml_lex_state

and string lexbuf =
    __ocaml_lex_string_rec lexbuf 33
and __ocaml_lex_string_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 204 "mix/mix_lexer.mll"
      ( STRING (Buffer.contents string_buf) )
# 449 "mix/mix_lexer.ml"

  | 1 ->
let
# 205 "mix/mix_lexer.mll"
               c
# 455 "mix/mix_lexer.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 1) in
# 206 "mix/mix_lexer.mll"
      ( Buffer.add_char string_buf (char_for_backslash c); string lexbuf )
# 459 "mix/mix_lexer.ml"

  | 2 ->
# 208 "mix/mix_lexer.mll"
      ( newline lexbuf; Buffer.add_char string_buf '\n'; string lexbuf )
# 464 "mix/mix_lexer.ml"

  | 3 ->
# 210 "mix/mix_lexer.mll"
      ( raise (Lexical_error "unterminated string") )
# 469 "mix/mix_lexer.ml"

  | 4 ->
let
# 211 "mix/mix_lexer.mll"
         c
# 475 "mix/mix_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 212 "mix/mix_lexer.mll"
      ( Buffer.add_char string_buf c; string lexbuf )
# 479 "mix/mix_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_string_rec lexbuf __ocaml_lex_state

and verbatim lexbuf =
    __ocaml_lex_verbatim_rec lexbuf 35
and __ocaml_lex_verbatim_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 216 "mix/mix_lexer.mll"
      ( VERBATIM (Buffer.contents string_buf) )
# 490 "mix/mix_lexer.ml"

  | 1 ->
# 218 "mix/mix_lexer.mll"
      ( raise (Lexical_error "unterminated verbatim") )
# 495 "mix/mix_lexer.ml"

  | 2 ->
# 220 "mix/mix_lexer.mll"
      ( newline lexbuf; Buffer.add_char string_buf '\n'; verbatim lexbuf )
# 500 "mix/mix_lexer.ml"

  | 3 ->
let
# 221 "mix/mix_lexer.mll"
         c
# 506 "mix/mix_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 222 "mix/mix_lexer.mll"
      ( Buffer.add_char string_buf c; verbatim lexbuf )
# 510 "mix/mix_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_verbatim_rec lexbuf __ocaml_lex_state

and invariant lexbuf =
    __ocaml_lex_invariant_rec lexbuf 38
and __ocaml_lex_invariant_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 226 "mix/mix_lexer.mll"
      ( INVARIANT (Buffer.contents string_buf) )
# 521 "mix/mix_lexer.ml"

  | 1 ->
# 228 "mix/mix_lexer.mll"
      ( raise (Lexical_error "unterminated invariant") )
# 526 "mix/mix_lexer.ml"

  | 2 ->
# 230 "mix/mix_lexer.mll"
      ( newline lexbuf; Buffer.add_char string_buf '\n'; invariant lexbuf )
# 531 "mix/mix_lexer.ml"

  | 3 ->
let
# 231 "mix/mix_lexer.mll"
         c
# 537 "mix/mix_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 232 "mix/mix_lexer.mll"
      ( Buffer.add_char string_buf c; invariant lexbuf )
# 541 "mix/mix_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_invariant_rec lexbuf __ocaml_lex_state

and assertion lexbuf =
    __ocaml_lex_assertion_rec lexbuf 42
and __ocaml_lex_assertion_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 236 "mix/mix_lexer.mll"
      ( ASSERT (Buffer.contents string_buf) )
# 552 "mix/mix_lexer.ml"

  | 1 ->
# 238 "mix/mix_lexer.mll"
      ( raise (Lexical_error "unterminated assert") )
# 557 "mix/mix_lexer.ml"

  | 2 ->
# 240 "mix/mix_lexer.mll"
      ( newline lexbuf; Buffer.add_char string_buf '\n'; assertion lexbuf )
# 562 "mix/mix_lexer.ml"

  | 3 ->
let
# 241 "mix/mix_lexer.mll"
         c
# 568 "mix/mix_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 242 "mix/mix_lexer.mll"
      ( Buffer.add_char string_buf c; assertion lexbuf )
# 572 "mix/mix_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_assertion_rec lexbuf __ocaml_lex_state

;;

